eprllib.RewardFunctions
=======================

.. automodule:: eprllib.RewardFunctions

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   RewardFunctions
   comfort_rewards
   energy_and_ashrae55simplemodel
   energy_and_cen15251
   energy_rewards
